@@ -104,13 +104,15 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
-import aws_cdk.core
+import aws_cdk.core as _aws_cdk_core_f4b25747
 
 
 class EventNotify(
-    aws_cdk.core.Construct,
+    _aws_cdk_core_f4b25747.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-events-notify.EventNotify",
 ):
@@ -121,7 +123,7 @@ class EventNotify(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: _aws_cdk_core_f4b25747.Construct,
         id: builtins.str,
         *,
         line_notify_token: typing.Optional[builtins.str] = None,
@@ -135,6 +137,10 @@ class EventNotify(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__983697ae0c841ff9396c872569908503f3b178d3ccafd540d76c1c1fec6cdd4c)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EventNotifyProps(line_notify_token=line_notify_token, slack=slack)
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -159,7 +165,11 @@ class EventNotifyProps:
 
         :stability: experimental
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__02ebe07fa9d1a749f691d8c3e288afaed85beeefaf28fccccb71a6d2a71fb24b)
+            check_type(argname="argument line_notify_token", value=line_notify_token, expected_type=type_hints["line_notify_token"])
+            check_type(argname="argument slack", value=slack, expected_type=type_hints["slack"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if line_notify_token is not None:
             self._values["line_notify_token"] = line_notify_token
         if slack is not None:
@@ -206,7 +216,7 @@ class ISlackEventNotify(typing_extensions.Protocol):
     :stability: experimental
     '''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="slackChannelName")
     def slack_channel_name(self) -> builtins.str:
         '''(experimental) slack Channel Name for Lambda send message to slack.
@@ -215,7 +225,7 @@ class ISlackEventNotify(typing_extensions.Protocol):
         '''
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="slackWebhookUrl")
     def slack_webhook_url(self) -> builtins.str:
         '''(experimental) slack Webhook Url for Lambda send message to slack.
@@ -233,7 +243,7 @@ class _ISlackEventNotifyProxy:
 
     __jsii_type__: typing.ClassVar[str] = "cdk-events-notify.ISlackEventNotify"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="slackChannelName")
     def slack_channel_name(self) -> builtins.str:
         '''(experimental) slack Channel Name for Lambda send message to slack.
@@ -242,7 +252,7 @@ class _ISlackEventNotifyProxy:
         '''
         return typing.cast(builtins.str, jsii.get(self, "slackChannelName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="slackWebhookUrl")
     def slack_webhook_url(self) -> builtins.str:
         '''(experimental) slack Webhook Url for Lambda send message to slack.
@@ -262,3 +272,21 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__983697ae0c841ff9396c872569908503f3b178d3ccafd540d76c1c1fec6cdd4c(
+    scope: _aws_cdk_core_f4b25747.Construct,
+    id: builtins.str,
+    *,
+    line_notify_token: typing.Optional[builtins.str] = None,
+    slack: typing.Optional[ISlackEventNotify] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__02ebe07fa9d1a749f691d8c3e288afaed85beeefaf28fccccb71a6d2a71fb24b(
+    *,
+    line_notify_token: typing.Optional[builtins.str] = None,
+    slack: typing.Optional[ISlackEventNotify] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
